
from cfitsio import *
from re import sub

# Long names for the CFITSIO routines
parse_input_url      = cfitsioc.ffiurl
parse_rootname       = cfitsioc.ffrtnm
parse_output_url     = cfitsioc.ffourl
parse_extspec        = cfitsioc.ffexts
parse_extnum         = cfitsioc.ffextn
parse_binspec        = cfitsioc.ffbins
parse_binrange       = cfitsioc.ffbinr
#open_memfile         = cfitsioc.ffomem
open_file            = cfitsioc.ffopen
reopen_file          = cfitsioc.ffreopen
create_file          = cfitsioc.ffinit
create_template      = cfitsioc.fftplt
flush_file           = cfitsioc.ffflus
close_file           = cfitsioc.ffclos
delete_file          = cfitsioc.ffdelt
file_name            = cfitsioc.ffflnm
file_mode            = cfitsioc.ffflmd
url_type             = cfitsioc.ffurlt
get_version          = cfitsioc.ffvers
uppercase            = cfitsioc.ffupch
get_errstatus        = cfitsioc.ffgerr
write_errmsg         = cfitsioc.ffpmsg
read_errmsg          = cfitsioc.ffgmsg
clear_errmsg         = cfitsioc.ffcmsg
report_error         = cfitsioc.ffrprt
compare_str          = cfitsioc.ffcmps
test_keyword         = cfitsioc.fftkey
test_record          = cfitsioc.fftrec
make_keyn            = cfitsioc.ffkeyn
make_nkey            = cfitsioc.ffnkey
get_keytype          = cfitsioc.ffdtyp
parse_value          = cfitsioc.ffpsvc
parse_template       = cfitsioc.ffgthd
ascii_tform          = cfitsioc.ffasfm
binary_tform         = cfitsioc.ffbnfm
get_tbcol            = cfitsioc.ffgabc
get_rowsize          = cfitsioc.ffgrsz
write_record         = cfitsioc.ffprec
#write_key            = cfitsioc.ffpky
write_key_unit       = cfitsioc.ffpunt
write_comment        = cfitsioc.ffpcom
write_history        = cfitsioc.ffphis
write_date           = cfitsioc.ffpdat
get_system_time      = cfitsioc.ffgstm
date2str             = cfitsioc.ffdt2s
time2str             = cfitsioc.fftm2s
str2date             = cfitsioc.ffs2dt
str2time             = cfitsioc.ffs2tm
write_key_longstr    = cfitsioc.ffpkls
write_key_longwarn   = cfitsioc.ffplsw
write_key_null       = cfitsioc.ffpkyu
write_key_str        = cfitsioc.ffpkys
write_key_log        = cfitsioc.ffpkyl
write_key_lng        = cfitsioc.ffpkyj
write_key_fixflt     = cfitsioc.ffpkyf
write_key_flt        = cfitsioc.ffpkye
write_key_fixdbl     = cfitsioc.ffpkyg
write_key_dbl        = cfitsioc.ffpkyd
write_key_fixcmp     = cfitsioc.ffpkfc
write_key_cmp        = cfitsioc.ffpkyc
write_key_fixdblcmp  = cfitsioc.ffpkfm
write_key_dblcmp     = cfitsioc.ffpkym
write_key_triple     = cfitsioc.ffpkyt
write_tdim           = cfitsioc.ffptdm
write_keys_str       = cfitsioc.ffpkns
write_keys_log       = cfitsioc.ffpknl
write_keys_lng       = cfitsioc.ffpknj
write_keys_fixflt    = cfitsioc.ffpknf
write_keys_flt       = cfitsioc.ffpkne
write_keys_fixdbl    = cfitsioc.ffpkng
write_keys_dbl       = cfitsioc.ffpknd
copy_key             = cfitsioc.ffcpky
write_imghdr         = cfitsioc.ffphps
write_grphdr         = cfitsioc.ffphpr
write_atblhdr        = cfitsioc.ffphtb
write_btblhdr        = cfitsioc.ffphbn
write_key_template   = cfitsioc.ffpktp
get_hdrspace         = cfitsioc.ffghsp
get_hdrpos           = cfitsioc.ffghps
movabs_key           = cfitsioc.ffmaky
movrel_key           = cfitsioc.ffmrky
find_nextkey         = cfitsioc.ffgnxk
read_record          = cfitsioc.ffgrec
read_card            = cfitsioc.ffgcrd
read_key_unit        = cfitsioc.ffgunt
read_keyn            = cfitsioc.ffgkyn
#read_key             = cfitsioc.ffgky
read_keyword         = cfitsioc.ffgkey
read_key_str         = cfitsioc.ffgkys
read_key_log         = cfitsioc.ffgkyl
read_key_lng         = cfitsioc.ffgkyj
read_key_flt         = cfitsioc.ffgkye
read_key_dbl         = cfitsioc.ffgkyd
read_key_cmp         = cfitsioc.ffgkyc
read_key_dblcmp      = cfitsioc.ffgkym
read_key_triple      = cfitsioc.ffgkyt
read_key_longstr     = cfitsioc.ffgkls
read_tdim            = cfitsioc.ffgtdm
decode_tdim          = cfitsioc.ffdtdm
read_keys_str        = cfitsioc.ffgkns
read_keys_log        = cfitsioc.ffgknl
read_keys_lng        = cfitsioc.ffgknj
read_keys_flt        = cfitsioc.ffgkne
read_keys_dbl        = cfitsioc.ffgknd
read_imghdr          = cfitsioc.ffghpr
read_atblhdr         = cfitsioc.ffghtb
read_btblhdr         = cfitsioc.ffghbn
header2str           = cfitsioc.ffh2st
update_card          = cfitsioc.ffucrd
#update_key           = cfitsioc.ffuky
update_key_null      = cfitsioc.ffukyu
update_key_str       = cfitsioc.ffukys
update_key_log       = cfitsioc.ffukyl
update_key_lng       = cfitsioc.ffukyj
update_key_fixflt    = cfitsioc.ffukyf
update_key_flt       = cfitsioc.ffukye
update_key_fixdbl    = cfitsioc.ffukyg
update_key_dbl       = cfitsioc.ffukyd
update_key_fixcmp    = cfitsioc.ffukfc
update_key_cmp       = cfitsioc.ffukyc
update_key_fixdblcmp = cfitsioc.ffukfm
update_key_dblcmp    = cfitsioc.ffukym
modify_record        = cfitsioc.ffmrec
modify_card          = cfitsioc.ffmcrd
modify_name          = cfitsioc.ffmnam
modify_comment       = cfitsioc.ffmcom
modify_key_null      = cfitsioc.ffmkyu
modify_key_str       = cfitsioc.ffmkys
modify_key_log       = cfitsioc.ffmkyl
modify_key_lng       = cfitsioc.ffmkyj
modify_key_fixflt    = cfitsioc.ffmkyf
modify_key_flt       = cfitsioc.ffmkye
modify_key_fixdbl    = cfitsioc.ffmkyg
modify_key_dbl       = cfitsioc.ffmkyd
modify_key_fixcmp    = cfitsioc.ffmkfc
modify_key_cmp       = cfitsioc.ffmkyc
modify_key_fixdblcmp = cfitsioc.ffmkfm
modify_key_dblcmp    = cfitsioc.ffmkym
insert_record        = cfitsioc.ffirec
insert_key_null      = cfitsioc.ffikyu
insert_key_str       = cfitsioc.ffikys
insert_key_log       = cfitsioc.ffikyl
insert_key_lng       = cfitsioc.ffikyj
insert_key_fixflt    = cfitsioc.ffikyf
insert_key_flt       = cfitsioc.ffikye
insert_key_fixdbl    = cfitsioc.ffikyg
insert_key_dbl       = cfitsioc.ffikyd
insert_key_fixcmp    = cfitsioc.ffikfc
insert_key_cmp       = cfitsioc.ffikyc
insert_key_fixdblcmp = cfitsioc.ffikfm
insert_key_dblcmp    = cfitsioc.ffikym
delete_key           = cfitsioc.ffdkey
delete_record        = cfitsioc.ffdrec
get_hdu_num          = cfitsioc.ffghdn
get_hdu_type         = cfitsioc.ffghdt
get_hduaddr          = cfitsioc.ffghad
movabs_hdu           = cfitsioc.ffmahd
movrel_hdu           = cfitsioc.ffmrhd
movnam_hdu           = cfitsioc.ffmnhd
get_num_hdus         = cfitsioc.ffthdu
create_img           = cfitsioc.ffcrim
create_tbl           = cfitsioc.ffcrtb
create_hdu           = cfitsioc.ffcrhd
insert_img           = cfitsioc.ffiimg
insert_atbl          = cfitsioc.ffitab
insert_btbl          = cfitsioc.ffibin
resize_img           = cfitsioc.ffrsim
delete_hdu           = cfitsioc.ffdhdu
copy_hdu             = cfitsioc.ffcopy
copy_header          = cfitsioc.ffcphd
copy_data            = cfitsioc.ffcpdt
set_hdustruc         = cfitsioc.ffrdef
set_hdrsize          = cfitsioc.ffhdef
write_theap          = cfitsioc.ffpthp
encode_chksum        = cfitsioc.ffesum
decode_chksum        = cfitsioc.ffdsum
write_chksum         = cfitsioc.ffpcks
update_chksum        = cfitsioc.ffupck
verify_chksum        = cfitsioc.ffvcks
get_chksum           = cfitsioc.ffgcks
set_bscale           = cfitsioc.ffpscl
set_tscale           = cfitsioc.fftscl
set_imgnull          = cfitsioc.ffpnul
set_btblnull         = cfitsioc.fftnul
set_atblnull         = cfitsioc.ffsnul
get_colnum           = cfitsioc.ffgcno
get_colname          = cfitsioc.ffgcnn
get_coltype          = cfitsioc.ffgtcl
get_num_rows         = cfitsioc.ffgnrw
get_num_cols         = cfitsioc.ffgncl
get_acolparms        = cfitsioc.ffgacl
get_bcolparms        = cfitsioc.ffgbcl
read_subset_sht      = cfitsioc.ffgsvi
read_subset_lng      = cfitsioc.ffgsvj
read_subset_int      = cfitsioc.ffgsvk
read_subset_flt      = cfitsioc.ffgsve
read_subset_dbl      = cfitsioc.ffgsvd
read_col_str         = cfitsioc.ffgcvs
#read_col_log         = cfitsioc.ffgcvl
read_col_byt         = cfitsioc.ffgcvb
#read_col_usht        = cfitsioc.ffgcvui
#read_col_ulng        = cfitsioc.ffgcvuj
read_col_sht         = cfitsioc.ffgcvi
read_col_lng         = cfitsioc.ffgcvj
#read_col_uint        = cfitsioc.ffgcvuk
read_col_int         = cfitsioc.ffgcvk
read_col_flt         = cfitsioc.ffgcve
read_col_dbl         = cfitsioc.ffgcvd
#read_col_cmp         = cfitsioc.ffgcvc
#read_col_dblcmp      = cfitsioc.ffgcvm
read_col_bit         = cfitsioc.ffgcx
read_descript        = cfitsioc.ffgdes
read_descripts       = cfitsioc.ffgdess
read_tblbytes        = cfitsioc.ffgtbb
#write_subset_byt     = cfitsioc.ffpssb
write_subset_usht    = cfitsioc.ffpssui
#write_subset_ulng    = cfitsioc.ffpssuj
write_subset_sht     = cfitsioc.ffpssi
write_subset_lng     = cfitsioc.ffpssj
#write_subset_uint    = cfitsioc.ffpssuk
write_subset_int     = cfitsioc.ffpssk
write_subset_flt     = cfitsioc.ffpsse
write_subset_dbl     = cfitsioc.ffpssd
#write_col         = cfitsioc.ffpcl
#write_col_str     = cfitsioc.ffpcls
#write_col_log     = cfitsioc.ffpcll
#write_col_byt     = cfitsioc.ffpclb
#write_col_usht     = cfitsioc.ffpclui
#write_col_ulng     = cfitsioc.ffpcluj
write_col_sht     = cfitsioc.ffpcli
write_col_lng     = cfitsioc.ffpclj
#write_col_uint     = cfitsioc.ffpcluk
write_col_int     = cfitsioc.ffpclk
write_col_flt     = cfitsioc.ffpcle
write_col_dbl     = cfitsioc.ffpcld
#write_col_cmp     = cfitsioc.ffpclc
#write_col_dblcmp  = cfitsioc.ffpclm
write_descript       = cfitsioc.ffpdes
write_tblbytes       = cfitsioc.ffptbb
insert_rows          = cfitsioc.ffirow
delete_rows          = cfitsioc.ffdrow
delete_rowlist       = cfitsioc.ffdrws
insert_col           = cfitsioc.fficol
insert_cols          = cfitsioc.fficls
delete_col           = cfitsioc.ffdcol
copy_col             = cfitsioc.ffcpcl
modify_vector_len    = cfitsioc.ffmvec
read_img_coord       = cfitsioc.ffgics
read_tbl_coord       = cfitsioc.ffgtcs
pix_to_world         = cfitsioc.ffwldp
world_to_pix         = cfitsioc.ffxypx
#init_wcs_img         = cfitsioc.ffiwcs
find_rows            = cfitsioc.fffrow
find_rows_cmp        = cfitsioc.fffrwc
select_rows          = cfitsioc.ffsrow
calc_rows            = cfitsioc.ffcrow
calculator           = cfitsioc.ffcalc
test_expr            = cfitsioc.fftexp
create_group         = cfitsioc.ffgtcr
insert_group         = cfitsioc.ffgtis
change_group         = cfitsioc.ffgtch
remove_group         = cfitsioc.ffgtrm
copy_group           = cfitsioc.ffgtcp
merge_groups         = cfitsioc.ffgtmg
compact_group        = cfitsioc.ffgtcm
verify_group         = cfitsioc.ffgtvf
open_group           = cfitsioc.ffgtop
add_group_member     = cfitsioc.ffgtam
get_num_members      = cfitsioc.ffgtnm
get_num_groups       = cfitsioc.ffgmng
open_member          = cfitsioc.ffgmop
copy_member          = cfitsioc.ffgmcp
transfer_member      = cfitsioc.ffgmtf
remove_member        = cfitsioc.ffgmrm
# End of long names for the CFITSIO routines

def ffgky(fitsfile, datatype, keyname):
  if datatype == TSTRING: func=read_key_str
  elif datatype == TLOGICAL: func=read_key_log
  elif datatype == TINT: func=read_key_int
  elif datatype == TLONG: func=read_key_lng
  elif datatype == TFLOAT: func=read_key_flt
  elif datatype == TDOUBLE: func=read_key_dbl
  status,value,comment=func(fitsfile, keyname)
  if status != 0: value=None;comment=None
  return status, value, comment
read_key = ffgky

def ffpky(fitsfile, datatype, keyname, value, comment=""):
  if datatype == TSTRING: func,dl=write_key_str,None
  elif datatype == TLOGICAL: func,dl=write_key_log,None
  elif datatype in [TINT, TSHORT, TLONG]: func,dl=write_key_lng,None
  elif datatype in [TFLOAT, TDOUBLE]: func,dl=write_key_dbl,-15
  if dl: return func(fitsfile, keyname, value, dl, comment)
  else: return func(fitsfile, keyname, value, comment)
write_key = ffpky

def ffuky(fitsfile, datatype, keyname, value, comment=""):
  if datatype == TSTRING: func,dl=update_key_str,None
  elif datatype == TLOGICAL: func,dl=update_key_log,None
  elif datatype in [TINT, TSHORT, TLONG]: func,dl=update_key_lng,None
  elif datatype in [TFLOAT, TDOUBLE]: func,dl=update_key_dbl,-15
  if dl: return func(fitsfile, keyname, value, dl, comment)
  else: return func(fitsfile, keyname, value, comment)
update_key = ffuky

def ffiky(fitsfile, datatype, keyname, value, comment=""):
  if datatype == TSTRING: func,dl=insert_key_str,None
  elif datatype == TLOGICAL: func,dl=insert_key_log,None
  elif datatype in [TINT, TSHORT, TLONG]: func,dl=insert_key_lng,None
  elif datatype in [TFLOAT, TDOUBLE]: func,dl=insert_key_dbl,-15
  if dl: return func(fitsfile, keyname, value, dl, comment)
  else: return func(fitsfile, keyname, value, comment)
insert_key = ffiky

